@@ -49,8 +49,8 @@ gengridxyvals(const int gridtype, const int gridID1, const int gridID2, const lo
 {
   Varray<double> xvals1, yvals1, xvals2, yvals2;
 
-  const bool lxvals = gridInqXvals(gridID1, nullptr) > 0;
-  const bool lyvals = gridInqYvals(gridID1, nullptr) > 0;
+  const auto lxvals = (gridInqXvals(gridID1, nullptr) > 0);
+  const auto lyvals = (gridInqYvals(gridID1, nullptr) > 0);
 
   if (gridtype == GRID_CURVILINEAR)
     {
@@ -336,6 +336,27 @@ gengrid(const int gridID1, const SelboxInfo &sbox)
   return gridID2;
 }
 
+static void
+copy_array_index(size_t n, const double *restrict v1, Varray<double> &v2, const std::vector<long> &index)
+{
+#ifdef _OPENMP
+#pragma omp parallel for if (n > 99999) default(shared) schedule(static)
+#endif
+  for (size_t i = 0; i < n; ++i) v2[i] = v1[index[i]];
+}
+
+static void
+copy_bounds_index(size_t n, size_t nv, const double *restrict v1, Varray<double> &v2, const std::vector<long> &index)
+{
+#ifdef _OPENMP
+#pragma omp parallel for if (n > 99999) default(shared) schedule(static)
+#endif
+  for (size_t i = 0; i < n; ++i)
+    {
+      for (size_t k = 0; k < nv; ++k) v2[i * nv + k] = v1[index[i] * nv + k];
+    }
+}
+
 int
 gengridcell(const int gridID1, const size_t gridsize2, const std::vector<long> &cellidx)
 {
@@ -361,45 +382,33 @@ gengridcell(const int gridID1, const size_t gridsize2, const std::vector<long> &
 
   if (gridHasCoordinates(gridID1))
     {
-      Varray<double> xvals1(gridsize1), yvals1(gridsize1);
-      Varray<double> xvals2(gridsize2), yvals2(gridsize2);
+      const auto *xvals1 = gridInqXvalsPtr(gridID1);
+      const auto *yvals1 = gridInqYvalsPtr(gridID1);
 
-      gridInqXvals(gridID1, xvals1.data());
-      gridInqYvals(gridID1, yvals1.data());
+      Varray<double> xyvals2(gridsize2);
 
-      for (size_t i = 0; i < gridsize2; ++i)
-        {
-          xvals2[i] = xvals1[cellidx[i]];
-          yvals2[i] = yvals1[cellidx[i]];
-        }
+      copy_array_index(gridsize2, xvals1, xyvals2, cellidx);
+      gridDefXvals(gridID2, xyvals2.data());
 
-      gridDefXvals(gridID2, xvals2.data());
-      gridDefYvals(gridID2, yvals2.data());
+      copy_array_index(gridsize2, yvals1, xyvals2, cellidx);
+      gridDefYvals(gridID2, xyvals2.data());
     }
 
   if (gridHasBounds(gridID1))
     {
       const auto nv = gridInqNvertex(gridID1);
-
-      Varray<double> xbounds1(nv * gridsize1), ybounds1(nv * gridsize1);
-      Varray<double> xbounds2(nv * gridsize2), ybounds2(nv * gridsize2);
-
-      gridInqXbounds(gridID1, xbounds1.data());
-      gridInqYbounds(gridID1, ybounds1.data());
+      const auto *xbounds1 = gridInqXboundsPtr(gridID1);
+      const auto *ybounds1 = gridInqYboundsPtr(gridID1);
 
       gridDefNvertex(gridID2, nv);
 
-      for (size_t i = 0; i < gridsize2; ++i)
-        {
-          for (int k = 0; k < nv; ++k)
-            {
-              xbounds2[i * nv + k] = xbounds1[cellidx[i] * nv + k];
-              ybounds2[i * nv + k] = ybounds1[cellidx[i] * nv + k];
-            }
-        }
+      Varray<double> xybounds2(nv * gridsize2);
 
-      gridDefXbounds(gridID2, xbounds2.data());
-      gridDefYbounds(gridID2, ybounds2.data());
+      copy_bounds_index(gridsize2, nv, xbounds1, xybounds2, cellidx);
+      gridDefXbounds(gridID2, xybounds2.data());
+
+      copy_bounds_index(gridsize2, nv, ybounds1, xybounds2, cellidx);
+      gridDefYbounds(gridID2, xybounds2.data());
     }
 
   if (gridHasArea(gridID1))
@@ -748,39 +757,41 @@ gencellgrid(int gridID1, long &gridsize2, std::vector<long> &cellidx)
 
   if (!gridHasCoordinates(gridID1)) cdo_abort("Grid cell coordinates missing!");
 
-  Varray<double> xvals(gridsize1), yvals(gridsize1);
-  gridInqXvals(gridID1, xvals.data());
-  gridInqYvals(gridID1, yvals.data());
+  {
+    Varray<double> xvals(gridsize1), yvals(gridsize1);
+    gridInqXvals(gridID1, xvals.data());
+    gridInqYvals(gridID1, yvals.data());
 
-  // Convert lat/lon units if required
-  cdo_grid_to_degree(gridID1, CDI_XAXIS, gridsize1, xvals.data(), "grid center lon");
-  cdo_grid_to_degree(gridID1, CDI_YAXIS, gridsize1, yvals.data(), "grid center lat");
+    // Convert lat/lon units if required
+    cdo_grid_to_degree(gridID1, CDI_XAXIS, gridsize1, xvals.data(), "grid center lon");
+    cdo_grid_to_degree(gridID1, CDI_YAXIS, gridsize1, yvals.data(), "grid center lat");
 
-  // find gridsize2
-  long maxcell = 0;
-  long nvals = 0;
-  for (size_t i = 0; i < gridsize1; ++i)
-    {
-      const auto xval = xvals[i];
-      const auto yval = yvals[i];
-      if (yval >= xlat1 && yval <= xlat2)
-        if ((xval >= xlon1 && xval <= xlon2) || (xval + 360 >= xlon1 && xval + 360 <= xlon2)
-            || (xval - 360 >= xlon1 && xval - 360 <= xlon2))
-          {
-            nvals++;
-            if (nvals > maxcell)
-              {
-                constexpr long cellinc = 4096;
-                maxcell += cellinc;
-                cellidx.resize(maxcell);
-              }
-            cellidx[nvals - 1] = i;
-          }
-    }
+    // find gridsize2
+    long maxcell = 0;
+    long nvals = 0;
+    for (size_t i = 0; i < gridsize1; ++i)
+      {
+        const auto xval = xvals[i];
+        const auto yval = yvals[i];
+        if (yval >= xlat1 && yval <= xlat2)
+          if ((xval >= xlon1 && xval <= xlon2) || (xval + 360 >= xlon1 && xval + 360 <= xlon2)
+              || (xval - 360 >= xlon1 && xval - 360 <= xlon2))
+            {
+              nvals++;
+              if (nvals > maxcell)
+                {
+                  constexpr long cellinc = 4096;
+                  maxcell += cellinc;
+                  cellidx.resize(maxcell);
+                }
+              cellidx[nvals - 1] = i;
+            }
+      }
 
-  if (nvals == 0) cdo_abort("No grid points found!");
+    if (nvals == 0) cdo_abort("No grid points found!");
 
-  gridsize2 = nvals;
+    gridsize2 = nvals;
+  }
 
   return gengridcell(gridID1, gridsize2, cellidx);
 }
@@ -912,19 +923,22 @@ window_box(const Field &field1, Field &field2, const long lat1, const long lat2,
 
 template <typename T>
 static void
-window_cell(const int nwpv, const Varray<T> &array1, Varray<T> &array2, const long gridsize2, const std::vector<long> &cellidx)
+window_cell(const int nwpv, const Varray<T> &v1, Varray<T> &v2, const long n, const std::vector<long> &index)
 {
   if (nwpv == 2)
     {
-      for (long i = 0; i < gridsize2; ++i)
+      for (long i = 0; i < n; ++i)
         {
-          array2[i * 2] = array1[cellidx[i] * 2];
-          array2[i * 2 + 1] = array1[cellidx[i] * 2 + 1];
+          v2[i * 2] = v1[index[i] * 2];
+          v2[i * 2 + 1] = v1[index[i] * 2 + 1];
         }
     }
   else
     {
-      for (long i = 0; i < gridsize2; ++i) array2[i] = array1[cellidx[i]];
+#ifdef _OPENMP
+#pragma omp parallel for if (n > 99999) default(shared) schedule(static)
+#endif
+      for (long i = 0; i < n; ++i) v2[i] = v1[index[i]];
     }
 }
 
