@@ -1,18 +1,8 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 
 #include <vector>
@@ -36,7 +26,7 @@ struct array
 
 struct cart
 {
-  double x[3];
+  double x[3] = { 0 };
 };
 
 struct geo
@@ -146,8 +136,6 @@ pow_ii(int x, int n)
 static struct cart
 circum_center(struct cart *v0, struct cart *v1, struct cart *v2)
 {
-  double cnorm;
-
   struct cart center;
   struct cart e1;
   struct cart e2;
@@ -184,7 +172,7 @@ circum_center(struct cart *v0, struct cart *v1, struct cart *v2)
   cu.x[1] = e1.x[2] * e2.x[0] - e1.x[0] * e2.x[2];
   cu.x[2] = e1.x[0] * e2.x[1] - e1.x[1] * e2.x[0];
 
-  cnorm = std::sqrt(cu.x[0] * cu.x[0] + cu.x[1] * cu.x[1] + cu.x[2] * cu.x[2]);
+  const auto cnorm = std::sqrt(cu.x[0] * cu.x[0] + cu.x[1] * cu.x[1] + cu.x[2] * cu.x[2]);
 
   ptmp1 = ((double *) center.x);
   ptmp2 = ((double *) cu.x);
@@ -1191,8 +1179,9 @@ initmask(int *mask, int ni, int nd)
 
 /*****************************************************************************/
 
+template <typename T>
 void
-gme_grid_restore(double *p, int ni, int nd)
+gme_grid_restore(T *p, int ni, int nd)
 {
   int j;
 
@@ -1262,6 +1251,10 @@ gme_grid_restore(double *p, int ni, int nd)
   return;
 }
 
+// Explicit instantiation
+template void gme_grid_restore(float *p, int ni, int nd);
+template void gme_grid_restore(double *p, int ni, int nd);
+
 /*****************************************************************************/
 
 void
