@@ -32,9 +32,9 @@ static VertexList vertices(12);
 void
 init(void)
 {
-  constexpr double pi_5 = M_PI * 0.2;
+  constexpr auto pi_5 = M_PI * 0.2;
   // first define the vertices of the icosahedron
-  const double z_w = 2.0 * std::acos(1.0 / (2.0 * std::sin(pi_5)));
+  const auto z_w = 2.0 * std::acos(1.0 / (2.0 * std::sin(pi_5)));
 
   // set poles first - it is simple
   vertices[0] = Vertex{ 0.0, 0.0, 1.0 };
@@ -52,9 +52,9 @@ init(void)
   for (int j = 1; j < 11; ++j)
     {
       // toggle the hemisphere
-      const double i_msgn = (j >= 6) ? -1 : 1;
+      const auto i_msgn = (j >= 6) ? -1.0 : 1.0;
       // compute the meridian angle for the base vertex.
-      const double z_rlon = (1.0 + i_mdist[j - 1]) * pi_5;
+      const auto z_rlon = (1.0 + i_mdist[j - 1]) * pi_5;
       // now initialize the coordinates
       vertices[j] = Vertex{ std::sin(z_w) * std::cos(z_rlon), std::sin(z_w) * std::sin(z_rlon), std::cos(z_w) * i_msgn };
     }
@@ -82,7 +82,7 @@ vertexForEdge(Lookup &lookup, VertexList &vertices, Index first, Index second)
 }
 
 static TriangleList
-subdivide(VertexList &vertices, TriangleList triangles)
+subdivide(VertexList &vertices, const TriangleList &triangles)
 {
   Lookup lookup;
   Triangle mid;
@@ -92,15 +92,14 @@ subdivide(VertexList &vertices, TriangleList triangles)
   for (size_t i = 0; i < n; ++i)
     {
       const auto &each = triangles[i];
-
       for (int edge = 0; edge < 3; edge++)
         {
           mid[edge] = vertexForEdge(lookup, vertices, each[edge], each[(edge + 1) % 3]);
         }
 
-      result[i * 4 + 0] = { { each[0], mid[0], mid[2] } };
-      result[i * 4 + 1] = { { each[1], mid[1], mid[0] } };
-      result[i * 4 + 2] = { { each[2], mid[2], mid[1] } };
+      result[i * 4 + 0] = { each[0], mid[0], mid[2] };
+      result[i * 4 + 1] = { each[1], mid[1], mid[0] };
+      result[i * 4 + 2] = { each[2], mid[2], mid[1] };
       result[i * 4 + 3] = mid;
     }
 
@@ -136,27 +135,27 @@ circumCenterMean(const Vertex &v0, const Vertex &v1, const Vertex &v2)
     counter clockwise order center: the coordinates of the circumcenter unless co-linear
   */
   // cu0, cu1, cu2: vector product of center:  e1 x e2
-  Vertex e1, e2;  // edges of the underlying planar triangle: v1-v0 ands v2-v0, respectively
+  // e1, e2: edges of the underlying planar triangle: v1-v0 ands v2-v0, respectively
 
-  e1 = v1 - v0;
-  e2 = v2 - v0;
-  Vertex cu0 = e1 % e2;
+  auto e1 = v1 - v0;
+  auto e2 = v2 - v0;
+  auto cu0 = e1 % e2;
   if ((cu0 * v0) < 0.0) cu0 = -cu0;
   d_normalize(cu0);
 
   e1 = v2 - v1;
   e2 = v0 - v1;
-  Vertex cu1 = e1 % e2;
+  auto cu1 = e1 % e2;
   if ((cu1 * v1) < 0.0) cu1 = -cu1;
   d_normalize(cu1);
 
   e1 = v0 - v2;
   e2 = v1 - v2;
-  Vertex cu2 = e1 % e2;
+  auto cu2 = e1 % e2;
   if ((cu2 * v2) < 0.0) cu2 = -cu2;
   d_normalize(cu2);
 
-  Vertex center = cu0 + cu1 + cu2;
+  auto center = cu0 + cu1 + cu2;
   d_normalize(center);
 
   return center;
@@ -166,9 +165,9 @@ size_t
 genIcosphereCoords(int subdivisions, bool lbounds, std::vector<double> &xvals, std::vector<double> &yvals,
                    std::vector<double> &xbounds, std::vector<double> &ybounds)
 {
-  auto mesh = makeIcosphere(subdivisions);
-  auto &vertices = mesh.first;
-  auto &triangles = mesh.second;
+  const auto mesh = makeIcosphere(subdivisions);
+  const auto &vertices = mesh.first;
+  const auto &triangles = mesh.second;
 
   const auto ncells = triangles.size();
   xvals.resize(ncells);
