@@ -1,18 +1,8 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 #ifndef SPECSPACE_H
 #define SPECSPACE_H
@@ -23,10 +13,18 @@
 
 #include "cdo_options.h"
 #include "transform.h"
-#include "array.h"
+#include "varray.h"
+
+enum class PolFlag
+{
+  UNDEF,
+  SP2FC,
+  FC2SP,
+  UV2DV,
+};
 
 class // FC_Transformation
-#ifdef __GNUG__
+#ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 FC_Transformation
@@ -45,10 +43,10 @@ public:
     if (Options::Use_FFTW)
       {
 #ifdef HAVE_LIBFFTW3
-        if (Options::cdoVerbose) cdoPrint("Using fftw3 lib");
+        if (Options::cdoVerbose) cdo_print("Using fftw3 lib");
         use_fftw = true;
 #else
-        if (Options::cdoVerbose) cdoPrint("LIBFFTW3 support not compiled in!");
+        if (Options::cdoVerbose) cdo_print("LIBFFTW3 support not compiled in!");
 #endif
       }
   }
@@ -73,13 +71,13 @@ public:
       {
         vtrig.resize(nlon);
         const auto status = fft_set(vtrig.data(), ifax, nlon);
-        if (status < 0) cdoAbort("FFT error!");
+        if (status < 0) cdo_abort("FFT error!");
       }
   }
 };
 
 class // SP_Transformation
-#ifdef __GNUG__
+#ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 SP_Transformation
@@ -88,18 +86,17 @@ public:
   FC_Transformation fcTrans;
   long nlat = 0;
   long ntr = 0;
-  long poldim = 0;
-  Varray<double> vpoli;
-  Varray<double> vpold;
-  Varray<double> vpol2;     // only for uv2dv
-  Varray<double> vpol3;     // only for uv2dv
-  Varray<double> vcoslat;   // only for scaluv with uv2dv
-  Varray<double> vrcoslat;  // only for scaluv with uv2dv
+  Varray<double> poli;
+  Varray<double> pold;
+  Varray<double> pol2;     // only for uv2dv
+  Varray<double> pol3;     // only for uv2dv
+  Varray<double> coslat;   // only for scaluv with uv2dv
+  Varray<double> rcoslat;  // only for scaluv with dv2uv
 
   SP_Transformation() {}
 
   void
-  init(long _nlon, long _nlat, long _ntr, int _flag, long _nlev = 0)
+  init(long _nlon, long _nlat, long _ntr, PolFlag polFlag, long _nlev = 0)
   {
     if (_nlon <= 0 || _nlat <= 0 || _ntr <= 0)
       {
@@ -113,28 +110,28 @@ public:
     ntr = _ntr;
 
     const long nsp = (ntr + 1) * (ntr + 2);
-    poldim = nsp / 2 * nlat;
+    const long poldim = (nsp / 2) * nlat;
 
-    varrayResize(vpoli, poldim);
-    varrayResize(vpold, poldim);
+    const auto numArrays = (polFlag == PolFlag::UV2DV) ? 2 : 1;
+    cdo_print("Allocate %d array%s to hold the Legendre polynoms: size=%ld Bytes\n", numArrays, numArrays > 1 ? "s" : "", poldim * 8);
 
-    if (_flag) varrayResize(vpol2, poldim);
-    if (_flag) varrayResize(vpol3, poldim);
+    if (polFlag == PolFlag::SP2FC) varrayResize(poli, poldim);
+    if (polFlag == PolFlag::FC2SP) varrayResize(pold, poldim);
 
-    vcoslat.resize(nlat);
-    vrcoslat.resize(nlat);
+    if (polFlag == PolFlag::UV2DV) varrayResize(pol2, poldim);
+    if (polFlag == PolFlag::UV2DV) varrayResize(pol3, poldim);
 
-    if (_flag)
-      after_legini_full(ntr, nlat, vpoli.data(), vpold.data(), nullptr, vpol2.data(), vpol3.data(), vcoslat.data());
-    else
-      after_legini(ntr, nlat, vpoli.data(), vpold.data(), vcoslat.data());
+    coslat.resize(nlat);
+    rcoslat.resize(nlat);
 
-    for (long jgl = 0; jgl < nlat; ++jgl) vrcoslat[jgl] = 1.0 / vcoslat[jgl];
+    after_legini_full(ntr, nlat, poli.data(), pold.data(), nullptr, pol2.data(), pol3.data(), coslat.data());
+
+    for (long jgl = 0; jgl < nlat; ++jgl) rcoslat[jgl] = 1.0 / coslat[jgl];
   }
 };
 
 class // DV_Transformation
-#ifdef __GNUG__
+#ifdef WARN_UNUSED
 [[gnu::warn_unused]]
 #endif
 DV_Transformation
